@@ -1,5 +1,6 @@
 import requests
 from bs4 import BeautifulSoup
+import random
 
 def get_question(number):
     url = "https://www.acmicpc.net/problem/" + str(number)
@@ -56,3 +57,8 @@ def get_memory_limit(number):
     soup = BeautifulSoup(response.text, "html.parser")
     memory_cut = soup.select_one("#problem-info > tbody > tr > td:nth-child(2)")
     return memory_cut.text
+
+def get_random_question():
+    url = "https://www.acmicpc.net/problem/" + random.randint(1000, 22934)
+    return url
+
